@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..10\n"; }
+BEGIN { $| = 1; print "1..11\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use Games::QuizTaker;
 $loaded = 1;
@@ -18,7 +18,7 @@ $loaded = 1;
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
-$Q1=Games::QuizTaker->new(FileName=>"sampleqa");
+$Q1=Games::QuizTaker->new(FileName=>"sampleqa",Score=>1);
 if($$Q1{_FileName} eq "sampleqa"){
   print"{_FileName} ............ ok 2\n";
 }else{
@@ -78,9 +78,16 @@ if($Max == 0){
 }
 
 my $Final=$Q3->get_Score;
-if($Final eq "1"){
-  print"Final Score set ........ ok 10\n";
+if(! defined $Final) {
+  print"Final Score default .... ok 10\n";
 }else{
-  print"Final Score set ........ not ok 10\n";
+  print"Final Score default .... not ok 10\n";
+}
+
+my $Final2=$Q1->get_Score;
+if(defined $Final2){
+  print"Final Score set ........ ok 11\n";
+}else{
+  print"Final Score set ........ not ok 11\n";
 }
  
